@@ -10,6 +10,20 @@ class WhatsAppUpdate:
     def get_message(self):
         return self.entry[0].changes[0].value.messages[0]
 
+    def get_message_text(self):
+        message = self.entry[0].changes[0].value.messages[0]
+        if message._type=="text":
+           return message.text
+        elif message._type=="interactive":
+            if message.interactive["type"] == "button_reply":
+                print("Interactive Message Text: {}".format(message.interactive["button_reply"]["title"]))
+                return message.interactive["button_reply"]["title"]
+            else:
+                print("There is no message text defined for this interactive type: {}".format(message.interactive["type"]))
+                return ""
+        else:
+            print("There is no message text defined for this message type: {}".format(message._type))
+
     def get_delivery(self):
         if self.entry[0].changes[0].value.statuses:
             return self.entry[0].changes[0].value.statuses[0].status
