@@ -55,7 +55,7 @@ class Action():
             WhatsAppInteraction(user=context["user_id"],
                             ProfileName = update.entry[0].changes[0].value.contacts[0].profile_name,
                             WaId = update.get_from(),
-                            text = update.get_message().text,
+                            text = update.get_message_text(),
                             ).save()
 
 
@@ -68,10 +68,33 @@ class Action():
             elif item["type"] == "message":
                 placeholder_dict = {**context}
                 placeholder_dict["name"] = update.entry[0].changes[0].value.contacts[0].profile_name
-                if update.get_message()._type =="text":
-                    placeholder_dict["echo"] = update.get_message().text
+                placeholder_dict["echo"] = update.get_message_text()
 
-                client.send_message(item["text"].format(
+                if "reply_buttons" in item.keys():
+                    buttons=[]
+                    for button in item["reply_buttons"]:
+                        buttons.append({
+                                            "type": "reply",
+                                            "reply": {
+                                                "id": button["id"],
+                                                "title": button["text"]
+                                            }
+                                        })
+
+                    button_dict={
+                                "type": "button",
+                                "body": {
+                                    "text": item["text"].format(**placeholder_dict)
+                                },
+                                "action": {
+                                    "buttons": buttons
+                                }
+                        }
+
+                    client.send_reply_button(recipient_id=update.get_from(),
+                                             button = button_dict)
+                else:
+                    client.send_message(item["text"].format(
                         **placeholder_dict), update.get_from())
                 
             elif item["type"] == "venue":
