@@ -108,7 +108,7 @@ class CommandHandler:
         self.callback = callback
 
     def check_update(self, update: WhatsAppUpdate):
-        if update.get_message()._type == "text" and update.get_message().text.strip("/").lower() == self.command.lower():
+        if update.get_message_text() != "" and update.get_message_text().strip("/").lower() == self.command.lower():
             return True
 
 
@@ -126,8 +126,8 @@ class RegexFilter:
         self.regex = regex
 
     def __call__(self, update: WhatsAppUpdate) -> bool:
-        if update.get_message()._type == "text":
-            return re.search(self.regex, update.get_message().text)
+        if update.get_message_text() != "":
+            return re.search(self.regex, update.get_message_text())
         else:
             return False
 
@@ -159,7 +159,7 @@ class FilterRasa:
         self.confidence = confidence
 
     def __call__(self, update: WhatsAppUpdate):
-        if update.get_message()._type != "text":
+        if update.get_message_text() == "":
             return False
         try:
             payload = json.dumps({
@@ -173,7 +173,7 @@ class FilterRasa:
 
             RASA_TOKEN = token_response.json()["access_token"]
             response = req.post(config["rasa"]["url"] + "/api/projects/default/logs", params={
-                                "q": update.get_message().text}, headers={'Authorization': 'Bearer {}'.format(RASA_TOKEN)},  timeout=(3, 8))
+                                "q": update.get_message_text()}, headers={'Authorization': 'Bearer {}'.format(RASA_TOKEN)},  timeout=(3, 8))
             print(response.json())
         except Exception as e:
             logger.debug(e)
